tuplettools
===========

.. automodule:: abjad.tools.tuplettools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.tuplettools.FixedDurationTuplet.FixedDurationTuplet.FixedDurationTuplet
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet
